#!/bin/bash
# Validation script
#
# Usage:
# ./validation-test.sh  user-proxyfile fts-user-endpoint channel-admin-endpoint
#
# Example:
# ./validation-test.sh /tmp/x509up_u17504 \
#             https://pcitgm01.cern.ch:8443/glite-data-transfer-fts/services/FileTransfer \
#             https://pcitgm01.cern.ch:8443/glite-data-transfer-fts/services/ChannelManagement
#
#

if [ $# != 3 ] ; then
    echo
    echo FTS service validation script
    echo
    echo "Usage:"
    echo "  $0 user-proxyfile fts-user-endpoint channel-admin-endpoint"
    echo
    exit 1
fi

TESTDIR=$(cd $(dirname $0); echo $PWD)

if [ -z "$TMPDIR" -a -d "/tmp" ]; then
    TMPDIR=/tmp
fi
JARDIR="$TMPDIR/"$(basename $0)-$$
# temporary files to be cleaned up
set -e
trap "rm -rf $JARDIR" EXIT

mkdir -p $JARDIR
cd $JARDIR
tar -xf $TESTDIR/validation-test.tar
CLASSPATH=''
for i in *.jar ; do CLASSPATH=${CLASSPATH}:$i ; done

OPTS="-Daxis.socketSecureFactory=org.glite.security.trustmanager.axis.AXISSocketFactory"
OPTS="-DsslCAFiles=/etc/grid-security/certificates/*.0 ${OPTS}"
OPTS="-DgridProxyFile=$1 ${OPTS}"
OPTS="-DftsEndpoint=$2 ${OPTS}"
OPTS="-DchannelEndpoint=$3 ${OPTS}"

echo "Running tarball testsuite"
echo "-------------------------"
echo
echo This is intended as an interactive test.
echo
echo "Using user-supplied proxyfile: $1"
echo "Please ensure this user's DN or VOMS role is in the security configuration of the service."
echo
echo "Testing fts user service endpoint: $2"
echo "Testing channel admin service endpoint: $3"
echo
echo Scanned classpath as: $CLASSPATH
echo
echo
echo Running validation testsuite: org.glite.data.transfer.fts.BasicFTSFuncTest
echo "Click EXIT afterwards to continue..."
echo "(It is normal to see your DN printed on the stdout)"
echo
java -cp $CLASSPATH $OPTS junit.awtui.TestRunner -noloading org.glite.data.transfer.fts.BasicFTSTestFunc
echo
echo
echo Running validation testsuite: org.glite.data.transfer.channel.BasicChannelTestFunc
echo "Click EXIT afterwards to finish test..."
echo "(It is normal to see your DN printed on the stdout)"
echo
java -cp $CLASSPATH $OPTS junit.awtui.TestRunner -noloading org.glite.data.transfer.channel.BasicChannelTestFunc
